@@ -1,14 +1,12 @@
-/* what to do */
-#include "readwrite.h"
-#include "exit.h"
 #include "buffer.h"
+#include "exit.h"
 
-char bspace[BUFFER_SMALL];
-buffer b = BUFFER_INIT(buffer_unixwrite,1,bspace,sizeof(bspace));
+char bspace[256];
+buffer b = BUFFER_INIT(buffer_unixwrite,1,bspace,sizeof bspace);
 
-static void outs(const char *s)
+static void puts(const char *s)
 {
- if (buffer_puts(&b,s) == -1) _exit(111);
+  if (buffer_puts(&b,s) == -1) _exit(111);
 }
 
 int main(int argc,char **argv)
@@ -23,20 +21,20 @@ int main(int argc,char **argv)
   value = argv[2];
   if (!value) _exit(100);
 
-  outs("const char ");
-  outs(name);
-  outs("[] = \"\\\n");
+  puts("const char ");
+  puts(name);
+  puts("[] = \"\\\n");
 
   while ((ch = *value++)) {
-    outs("\\");
+    puts("\\");
     octal[3] = 0;
     octal[2] = '0' + (ch & 7); ch >>= 3;
     octal[1] = '0' + (ch & 7); ch >>= 3;
     octal[0] = '0' + (ch & 7);
-    outs(octal);
+    puts(octal);
   }
 
-  outs("\\\n\";\n");
+  puts("\\\n\";\n");
   if (buffer_flush(&b) == -1) _exit(111);
   _exit(0);
 }
