@@ -10,7 +10,7 @@
 stralloc sanumber = {0};
 char strnum[FMT_ULONG];
 
-int getnumber(char *buf, int len, unsigned long *u)
+int getnumber(char *buf,int len,unsigned long *u)
 {
   if (!stralloc_copyb(&sanumber,buf,len)) return -1;
   if (!stralloc_0(&sanumber)) return -1;
@@ -18,7 +18,7 @@ int getnumber(char *buf, int len, unsigned long *u)
   return 0;
 }
 
-int getaddressasbit(char *ip, int prefix, stralloc *ip4string)
+int getaddressasbit(char *ip,int prefix,stralloc *ip4string)
 {
   int count;
   int i;
@@ -73,13 +73,14 @@ int getbitasaddress(stralloc *ip4string)
   int num = 0;
   int value = 256;
   int prefix = ip4string->len - 1;
+  const char zero = '0'; 
   
   if (!stralloc_copys(&buffer,"")) return -1;
   if (!stralloc_copys(&ipaddr,"")) return -1;
   
   for (iplen = 1; iplen <= prefix; iplen++) {
     if (!stralloc_copyb(&buffer,ip4string->s + iplen,1)) return -1;
-    if (byte_diff(buffer.s,1,"0") != 0) 
+    if (byte_diff(buffer.s,1,&zero) != 0) 
       { num += (value/2); value /= 2; }
     else 
       { value /= 2; }
