@@ -1,5 +1,4 @@
 ld="`head -1 ../conf-ld`"
-qlibs="`head -1 ../conf-qlibs`"
 systype="`cat systype`"
 
 flag=0
@@ -15,4 +14,4 @@ rm -f trycpp.o
 
 cat warn-auto.sh
 echo 'main="$1"; shift'
-echo exec "$ld" -L"${qlibs}" '-o "$main" "$main".o ${1+"$@"} -ldnsresolv -lqlibs'
+echo exec "$ld" '-o "$main" "$main".o ${1+"$@"}'
