@@ -11,7 +11,7 @@ int ssl_cca(SSL_CTX *ctx,const char *certfile)
 
   SSL_CTX_set_client_CA_list(ctx,x);
 
-  SSL_CTX_set_verify(ctx,SSL_VERIFY_PEER | SSL_VERIFY_CLIENT_ONCE | SSL_VERIFY_FAIL_IF_NO_PEER_CERT,0);
+  SSL_CTX_set_verify(ctx,SSL_VERIFY_PEER | SSL_VERIFY_FAIL_IF_NO_PEER_CERT,0);
 
   return 1;
 }
