@@ -1,5 +1,4 @@
 #include <unistd.h>
-#include <openssl/opensslv.h>
 #include <openssl/x509.h>
 #include "fmt.h"
 #include "pathexec.h"
@@ -20,15 +19,16 @@ static stralloc etemp = {0};
 #define set_env_id(n,e,v) \
 if (!set_env_name_entry((n),(e),(v))) return 0
 
-static int env_val(const char *env,const char *val,int len) {
+static int env_val(const char *env,const void *val,int len) {
+  const char *v = val;
   if (envsa) {
     if (!stralloc_cats(envsa,env)) return 0;
     if (!stralloc_catb(envsa,"=",1)) return 0;
-    if (!stralloc_catb(envsa,val,len)) return 0;
+    if (!stralloc_catb(envsa,v,len)) return 0;
     if (!stralloc_0(envsa)) return 0;
     return 1;
   }
-  if (!stralloc_copyb(&etemp,val,len)) return 0;
+  if (!stralloc_copyb(&etemp,v,len)) return 0;
   if (!stralloc_0(&etemp)) return 0;
   return pathexec_env(env,etemp.s);
 }
@@ -60,7 +60,7 @@ static int set_env_name_entry(X509_NAME *xname,const char *env,int nid) {
 }
 
 int ssl_session_vars(SSL *ssl) {
-  char *x;
+  unsigned char *x;
   SSL_SESSION *session;
   int n;
   int m;
