@@ -74,7 +74,10 @@ int ssl_io(SSL *ssl,int fdleft,int fdright,unsigned int timeout) {
       io1->events = IOPAUSE_WRITE;
     }
 
-    taia_now(&now);
+    if (taia_now(&now) == -1) {
+      errno = error_timeout;
+      goto bomb;
+    }
     taia_uint(&deadline,timeout);
     taia_add(&deadline,&now,&deadline);
     iopause(x,xlen,&deadline,&now);
@@ -147,7 +150,7 @@ events:
 	leftpos += r;
 	if (leftpos == leftlen) {
 	  leftstatus = 0;
-	  if (r = ssl_pending(ssl)) {
+	  if ((r = ssl_pending(ssl))) {
 	    if (r > sizeof leftbuf) r = sizeof leftbuf;
 	    r = SSL_read(ssl,leftbuf,r);
 	    ssl_errno = SSL_get_error(ssl,r);
