@@ -11,7 +11,10 @@ int ssl_timeoutaccept(SSL *ssl,unsigned int timeout)
   int rfd;
   int wfd;
 
-  taia_now(&now);
+  if (taia_now(&now) == 1) {
+    errno = error_timeout;
+    return -1;
+  }
   taia_uint(&deadline,timeout);
   taia_add(&deadline,&now,&deadline);
 
@@ -38,7 +41,10 @@ int ssl_timeoutaccept(SSL *ssl,unsigned int timeout)
       if (x.fd == -1) return -1;
     }
     for (;;) {
-      taia_now(&now);
+      if (taia_now(&now) == 1) {
+        errno = error_timeout;
+        return -1;
+      }
       iopause(&x,1,&deadline,&now);
       if (x.revents) break;
       if (taia_less(&deadline,&now))
