@@ -115,7 +115,7 @@ const char *cadir = auto_cadir;
 const char *ciphers = auto_ciphers;
 int verifydepth = 1;
 const char *dhfile = auto_dhfile;
-int rsalen = 1024;
+int rsalen = SSL_RSA_LEN;
 
 int pi[2];
 int po[2];
@@ -138,6 +138,9 @@ const char *fnrules = 0;
 void drop_nomem(void) {
   strerr_die3sys(111,self,DROP,"out of memory");
 }
+void drop_notemp(void) {
+  strerr_die3sys(111,self,DROP,"out of timestamps");
+}
 void cats(const char *s) {
   if (!stralloc_cats(&tmp,s)) drop_nomem();
 }
@@ -178,9 +181,9 @@ void env_set(void) {
   if (!stralloc_cats(&envplus,"")) return;
 
   elen = 0;
-  for (i = 0;environ[i];++i)
+  for (i = 0; environ[i]; ++i)
     ++elen;
-  for (i = 0;i < envplus.len;++i)
+  for (i = 0; i < envplus.len; ++i)
     if (!envplus.s[i])
       ++elen;
 
@@ -188,11 +191,11 @@ void env_set(void) {
   if (!e) return;
 
   elen = 0;
-  for (i = 0;environ[i];++i)
+  for (i = 0; environ[i]; ++i)
     e[elen++] = environ[i];
 
   j = 0;
-  for (i = 0;i < envplus.len;++i)
+  for (i = 0; i < envplus.len; ++i)
     if (!envplus.s[i]) {
       split = str_chr(envplus.s + j,'=');
       for (t = 0;t < elen;++t)
@@ -309,7 +312,7 @@ int doit(int t) {
     env("TCP6REMOTEPORT",remoteportstr);
     env("TCP6REMOTEHOST",remotehost);
   }
-  env("TCPREMOTEIP",remoteipstr);
+  env("TCPREMOTEIP",stripaddr);
   env("TCPREMOTEPORT",remoteportstr);
   env("TCPREMOTEHOST",remotehost);
   if (!mappedv4) {
@@ -672,34 +675,34 @@ int main(int argc,char * const *argv) {
     localport = ntohs(se->s_port);
   }
 
-  if (x = env_get("VERIFYDEPTH")) {
+  if ((x = env_get("VERIFYDEPTH"))) {
     scan_ulong(x,&u);
     verifydepth = u;
   }
 
-  if (x = env_get("CAFILE")) cafile = x;
+  if ((x = env_get("CAFILE"))) cafile = x;
   if (cafile && str_equal(cafile,"")) cafile = 0;
 
-  if (x = env_get("CCAFILE")) ccafile = x;
+  if ((x = env_get("CCAFILE"))) ccafile = x;
   if (ccafile && str_equal(ccafile,"")) ccafile = 0;
   if (!flagclientcert) ccafile = 0;
 
-  if (x = env_get("CADIR")) cadir = x;
+  if ((x = env_get("CADIR"))) cadir = x;
   if (cadir && str_equal(cadir,"")) cadir= 0;
 
-  if (x = env_get("CERTCHAINFILE")) certchainfile = x;
+  if ((x = env_get("CERTCHAINFILE"))) certchainfile = x;
   if (certchainfile && str_equal(certchainfile,"")) certchainfile = 0;
 
-  if (x = env_get("CERTFILE")) certfile = x;
+  if ((x = env_get("CERTFILE"))) certfile = x;
   if (certfile && str_equal(certfile,"")) certfile = 0;
 
-  if (x = env_get("KEYFILE")) keyfile = x;
+  if ((x = env_get("KEYFILE"))) keyfile = x;
   if (keyfile && str_equal(keyfile,"")) keyfile = 0;
 
-  if (x = env_get("DHFILE")) dhfile = x;
+  if ((x = env_get("DHFILE"))) dhfile = x;
   if (dhfile && str_equal(dhfile,"")) dhfile = 0;
 
-  if (x = env_get("CIPHERS")) ciphers = x;
+  if ((x = env_get("CIPHERS"))) ciphers = x;
   if (ciphers && str_equal(ciphers,"")) ciphers = 0;
 
   if (setsid() == -1)
@@ -789,8 +792,12 @@ int main(int argc,char * const *argv) {
   if (!ssl_cca(ctx,ccafile))
     strerr_die3x(111,self,FATAL,"unable to load client CA list");
 
-  if (!ssl_params(ctx,dhfile,rsalen))
-    strerr_die3x(111,self,FATAL,"unable to set cipher parameters");
+  if (!ssl_params_rsa(ctx,rsalen))
+    strerr_die2x(111,FATAL,"unable to set RSA parameters");
+  if (!ssl_params_dh(ctx,dhfile))
+    strerr_die2x(111,FATAL,"unable to set DH parameters");
+  if (!ssl_params_ecdh(ctx))
+    strerr_warn1("unable to set ECDH parameters",0);
 
   if (flagafter) {
     if (gid) if (prot_gid(gid) == -1)
@@ -821,19 +828,25 @@ int main(int argc,char * const *argv) {
   printstatus();
 
   for (;;) {
+    int pause_ret, read_ret;
     if (!flagexit) spawn(s,argc,argv);
 
     sig_unblock(sig_child);
     io[0].fd = selfpipe[0];
     io[0].events = IOPAUSE_READ;
-    taia_now(&stamp);
+    if (taia_now(&stamp) == -1) drop_notemp();
     taia_uint(&deadline,3600);
     taia_add(&deadline,&stamp,&deadline);
-    iopause(io,1,&deadline,&stamp);
+    pause_ret = iopause(io,1,&deadline,&stamp);
     sig_block(sig_child);
 
     if (flagexit && !numchildren) _exit(0);
-    while (buffer_unixread(selfpipe[0],&ch,1) == 1)
+    while ((read_ret=buffer_unixread(selfpipe[0],&ch,1)) == 1)
       ;
+    if ((pause_ret > 0) && (read_ret == 0)) {
+      flagexit = 1;
+      --numchildren;
+    }
+    if (flagexit && !numchildren) _exit(0);
   }
 }
