@@ -14,11 +14,17 @@ int timeoutconn6(int s,char ip[16],uint16 port,unsigned int timeout,uint32 netif
     if ((errno != error_wouldblock) && (errno != error_inprogress)) return -1;
     x.fd = s;
     x.events = IOPAUSE_WRITE;
-    taia_now(&now);
+    if (taia_now(&now) == -1) {
+      errno = error_timeout;
+      return -1;
+    }
     taia_uint(&deadline,timeout);
     taia_add(&deadline,&now,&deadline);
     for (;;) {
-      taia_now(&now);
+      if (taia_now(&now) == -1) {
+        errno = error_timeout;
+        return -1;
+      }
       iopause(&x,1,&deadline,&now);
       if (x.revents) break;
       if (taia_less(&deadline,&now)) {
