@@ -7,11 +7,29 @@
 #define UCSPISSL_H
 
 #include <openssl/ssl.h>
+#include <openssl/rsa.h>
 #include <openssl/err.h>
+#include <openssl/opensslv.h>
+#ifdef SSL_TXT_ECDH
+#include <openssl/ec.h>
+#endif
 #include "stralloc.h"
 
 #define SSL_NAME_LEN 256
+#define SSL_RSA_LEN 2048
 
+#if defined (LIBRESSL_VERSION_NUMBER)
+#define ssl_client() (ssl_context(TLS_client_method()))
+#define ssl_server() (ssl_context(TLS_server_method()))
+#else
+#define SSLv2_DISABLE
+#define SSLv3_DISABLE
+// #define TLSv1_DISABLE
+#define ssl_client() (ssl_context(SSLv23_client_method()))
+#define ssl_server() (ssl_context(SSLv23_server_method()))
+#endif
+
+#define ssl_errstr() (SSL_load_error_strings())
 extern int ssl_errno;
 extern int ssl_io(SSL *,int,int,unsigned int);
 extern SSL_CTX *ssl_context(const SSL_METHOD *);
@@ -24,14 +42,14 @@ extern int ssl_ca(SSL_CTX *,const char *,const char *,int);
 extern int ssl_cca(SSL_CTX *,const char *);
 extern int ssl_ciphers(SSL_CTX *,const char *);
 extern int ssl_verify(SSL *,const char *);
-extern int ssl_params(SSL_CTX *,const char *,int);
+extern int ssl_params_rsa(SSL_CTX *,int);
+extern int ssl_params_dh(SSL_CTX *,const char *);
+extern int ssl_params_ecdh(SSL_CTX *);
 extern int ssl_server_env(SSL *,stralloc *);
 extern int ssl_client_env(SSL *,stralloc *);
 extern char *ssl_error_str(int);
 extern int ssl_error(int (*)(const char *));
 
-#define ssl_client() (ssl_context(SSLv23_client_method()))
-#define ssl_server() (ssl_context(SSLv23_server_method()))
 #define ssl_errstr() (SSL_load_error_strings())
 #define ssl_free(ssl) (SSL_free((ssl)))
 #define ssl_close(ssl) (close(SSL_get_fd((ssl))))
